@@ -13,7 +13,7 @@ use Carp;
 use strict;
 use warnings;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 my $Time_HiRes_avail;
 my $color_avail;
@@ -107,6 +107,15 @@ $Devel::DumpTrace::NO_PPI
     $DUMPTRACE_COLOR = $ENV{DUMPTRACE_COLOR} || '';
     if ($DUMPTRACE_COLOR) {
         if ($color_avail) {
+            if ($DUMPTRACE_COLOR =~ /^\d+$/) {
+                my $bg = $DUMPTRACE_COLOR >> 4;
+                my $fg = $DUMPTRACE_COLOR & 7;
+                my $bold = ($DUMPTRACE_COLOR & 8) != 0;
+                my @c = ("black","red","green","yellow",
+                         "blue","magenta","cyan","white");
+                $DUMPTRACE_COLOR = ($bold ? "bold " : "") . $c[$fg]
+                    . ($bg ? " on_" . $c[$bg & 7] : "");
+            }
             $DUMPTRACE_COLOR = Term::ANSIColor::color($DUMPTRACE_COLOR);
             our $DUMPTRACE_RESET = Term::ANSIColor::color('reset');
         } else {
@@ -293,8 +302,10 @@ sub _abbrev_style_new {
 	    ABBREV_NONE,)[$TRACE % 10]
 }
 
-*_display_style = *_display_style_old;
-*_abbrev_style = *_abbrev_style_old;
+BEGIN {
+    *_display_style = *_display_style_old;
+    *_abbrev_style = *_abbrev_style_old;
+}
 
 sub _package_style {
     return $TRACE >= 100;
@@ -349,9 +360,18 @@ sub refresh_pads {
 }
 
 our $last_dumptrace = '';
-my @dt_prefix = ("      ",">     ",">>    ",">>>   ",">>>>  ",">>>>> ",
-                 "     \t         ",">    \t         ",">>   \t         ",
-                 ">>>  \t         ",">>>> \t         ",">>>>>\t         ",
+my @dt_prefix = ("      ",            ### not used
+                 ">     ",            ### not used
+                 ">>    ",            # to display current file/line/sub
+                 ">>>   ",            # raw statement
+                 ">>>>  ",            # with var substitution, before execution
+                 ">>>>> ",            # with var substitution after execution
+                 "     \t         ",  ### not used
+                 ">    \t         ",  ### not used
+                 ">>   \t         ",  ### not used
+                 ">>>  \t         ",  # raw statetment
+                 ">>>> \t         ",  # with var substitution, before execution
+                 ">>>>>\t         ",  # with var substitution after execution
                  "");
 
 sub dumptrace {
@@ -611,9 +631,11 @@ sub hash_repr {
                       %{$hashref};
         $hash = $cdh->{PHASH};
     } else {
-	# Hash::SafeKeysLLsafekeys will not reset an active `each` iterator
+	# Hash::SafeKeys::safekeys will not reset an active `each` iterator
+        my $it = Hash::SafeKeys::save_iterator_state($hashref);
 	$hash = { map { dump_scalar($_) => dump_scalar($hashref->{$_}) } 
-		  safekeys %$hashref };
+		  keys %$hashref };
+        Hash::SafeKeys::restore_iterator_state($hashref,$it);
     }
 
     my @r;
@@ -626,7 +648,9 @@ sub hash_repr {
 	    $HASH_PAIR_SEPARATOR, @keys );
     } else {
 	# safekeys does not reset an active `each` iterator (RT#77673)
-	@r = map { [ $_ => $hash->{$_} ] } _condsort(safekeys %$hash);
+        my $it = Hash::SafeKeys::save_iterator_state($hash);
+	@r = map { [ $_ => $hash->{$_} ] } _condsort(keys %$hash);
+        Hash::SafeKeys::restore_iterator_state($hash,$it);
     }
 
     if (@keys == 0 && Devel::DumpTrace::CachedDisplayedHash->is($hashref)) {
@@ -1114,7 +1138,7 @@ Devel::DumpTrace - Evaluate and print out each line before it is executed.
 
 =head1 VERSION
 
-0.24
+0.25
 
 =head1 SYNOPSIS
 
@@ -1365,9 +1389,9 @@ by setting C<$Devel::DumpTrace::DUMPTRACE_FH> to the desired
 I/O handle:
 
     BEGIN {
-       # if Devel::DumpTrace is loaded, direct output to xtrace.txt
+       # if Devel::DumpTrace is loaded, direct output to trace.txt
        if ($INC{'Devel/DumpTrace.pm'}) {
-          open $Devel::DumpTrace::DUMPTRACE_FH, '>', '/path/xtrace.txt';
+          open $Devel::DumpTrace::DUMPTRACE_FH, '>', '/path/trace.txt';
        }
     }
 
@@ -1519,8 +1543,10 @@ All output from this module is for diagnostics.
 
 =head1 DEPENDENCIES
 
-C<Devel::DumpTrace> requires the L<PadWalker|PadWalker>
-and L<Scalar::Util|Scalar::Util> modules.
+L<PadWalker|PadWalker> for arbitrary access to lexical variables.
+
+L<Scalar::Util|Scalar::Util> for the reference identification
+convenience methods.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -1692,7 +1718,7 @@ Marty O'Brien, E<lt>mob at cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2015 Marty O'Brien.
+Copyright 2010-2016 Marty O'Brien.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
