@@ -32,7 +32,7 @@ eval {use PPI;
 
 
 
-$Devel::DumpTrace::PPI::VERSION = '0.23';
+$Devel::DumpTrace::PPI::VERSION = '0.25';
 use constant ADD_IMPLICIT_ => 1;
 use constant DECORATE_FOR => 1;
 use constant DECORATE_FOREACH => 1;
@@ -103,7 +103,7 @@ sub _update_ppi_src_for_file {
 
     # use  reverse ... ?
     # then the child statements will be decorated before their parents
-    # if use reverse, then _update_ppi_src_for_element should unshift non push
+    # if use reverse, then _update_ppi_src_for_element should unshift not push
 
     foreach my $element (_DECORATE_REVERSE ? reverse @$statements
                                            : @$statements) {
@@ -1471,7 +1471,7 @@ Devel::DumpTrace::PPI - PPI-based version of Devel::DumpTrace
 
 =head1 VERSION
 
-0.24
+0.25
 
 =head1 SYNOPSIS
 
@@ -1514,7 +1514,7 @@ parser and makes a few other features available, including
 =item * handling statements with chained assignments of complex assignment
 expressions
 
-  $ perl -d:DumpTrace=verbose -e '$a=$b[$c=2]="foo"'
+  $ perl -d:DumpTrace::noPPI=verbose -e '$a=$b[$c=2]="foo"'
   >>  -e:1:[__top__]:
   >>>              $a=$b[$c=2]="foo"
   >>>>             $a=()[undef=2]="foo"
@@ -1534,7 +1534,7 @@ expressions
   @a = (1 + 2,
         3 + $b);
 
-  $ perl -d:DumpTrace=verbose multiline.pl
+  $ perl -d:DumpTrace::noPPI=verbose multiline.pl
   >>  multiline.pl:1:[__top__]:
   >>>              $b = 4;
   >>>>>            4 = 4;
@@ -1560,7 +1560,7 @@ expressions
 
 =item * string literals with variable names
 
-  $ perl -d:DumpTrace=verbose -e '$email = q/mob@cpan.org/'
+  $ perl -d:DumpTrace::noPPI=verbose -e '$email = q/mob@cpan.org/'
   >>  -e:1:[__top__]:
   >>>              $email = q/mob@cpan.org/
   >>>>             $email = q/mob().org/
@@ -1575,7 +1575,7 @@ expressions
 
 =item * Better recognition of Perl's magic variables
 
-  $ perl -d:DumpTrace=verbose -e '$"="\t";'  -e 'print join $", 3, 4, 5'
+  $ perl -d:DumpTrace::noPPI=verbose -e '$"="\t";'  -e 'print join $", 3, 4, 5'
   >>  -e:1:[__top__]:
   >>>              $"="\t";
   >>>>>            $"="\t";
@@ -2046,7 +2046,7 @@ Marty O'Brien, E<lt>mob at cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2015 Marty O'Brien.
+Copyright 2010-2016 Marty O'Brien.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
