@@ -8,7 +8,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw();
 our @EXPORT_OK = qw(shorten_scalar shorten_array shorten_hash);
 our %EXPORT_TAGS = (all => [ @EXPORT_OK ]);
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 our $DOTDOTDOT = '...';
 our $DOTDOTDOT_LENGTH = length($DOTDOTDOT);
@@ -211,7 +211,7 @@ sub shorten_array {
 		# that last element in when there is a low probability
 		# that it will work ...
 
-		last if ++$insert_fails > 100;
+		last if ++$insert_fails > 20;
 	    }
 	}
 
@@ -222,7 +222,7 @@ sub shorten_array {
 	for my $i (0 .. $n-1) {
 	    last if $len > $maxlen;
 	    my $excl = ($i>0 && !$inc[$i-1]) + ($i<$n-1 && !$inc[$i+1]) + 0;
-	    my $dlen = defined($array->[$i])&&length($array->[$i])
+	    my $dlen = defined($array->[$i]) && length($array->[$i])
 		+ $seplen + $dotslen * ($excl - 1);
 	    if ($len + $dlen <= $maxlen) {
 		$inc[$i] = 1;
@@ -265,53 +265,61 @@ sub shorten_hash {
 	$sep2 = length($sep2);
     }
 
-    my $total_len = -$sep1;
-    my @safekeys = safekeys %$hash;
-    for my $k (@safekeys) {
-	$total_len += length($k) + length($hash->{$k}) + $sep1 + $sep2;
+    # save iterator in case we are already inside  each %$hash
+    my $it = Hash::SafeKeys::save_iterator_state($hash);
+
+    # performance is greatly improved in v0.07 as we avoid calling
+    # keys %$hash  in list context on a possibly large hash
+
+    my $total_len = -$sep1 + ($sep1+$sep2) * keys %$hash;
+    while (my ($k,$v) = each %$hash) {
+        $total_len += length($k) + length($v);
 	last if $total_len > $maxlen;
     }
     if ($total_len <= $maxlen) {
 	# ok to include all elements
-	return map { [ $_ , $hash->{$_} ] } @safekeys;
+	my @all_elements = map { [ $_ , $hash->{$_} ] } keys %$hash;
+        Hash::SafeKeys::restore_iterator_state($hash,$it);
+        return @all_elements;
     }
 
-    my @r = ();
     my @hashkeys = ();
-    my $hashkey = {};
-
+    my $hk1 = {};
+    my $hk1_skip_key = 0;
+    my %key;
     if (@key > 0) {
-	my %key = map { $_ => 1 } @key;
-	if (100 > @safekeys) {
+	%key = map { $_ => 1 } @key;
+	if (100 > keys %$hash) {
 	    @hashkeys = sort {
-		($key{$b}||0) <=> ($key{$a}||0) 
-		    || $a cmp $b
-	    } @safekeys;
+		($key{$b}||0) <=> ($key{$a}||0) || $a cmp $b
+	    } keys %$hash;
 	} else {
-	    @hashkeys = @key = grep { defined $key{$_} } @key;
-	    push @hashkeys, grep { !defined $key{$_} } @safekeys;
+            @hashkeys = grep {  defined $key{$_} } @key;
+            $hk1 = $hash;
+            $hk1_skip_key = 1;
 	}
+    } elsif (100 > keys %$hash || $HASHREPR_SORTKEYS) {
+        @hashkeys = sort keys %$hash;
     } else {
-	if (100 > @safekeys) {
-	    @hashkeys = sort @safekeys;
-	} else {
-	    $hashkey = $hash;
-	}
+        $hk1 = $hash;
     }
 
     my $len = 3;
-    my @sk = safekeys %$hashkey;
-    if ($HASHREPR_SORTKEYS) {
-	@sk = sort @sk;
-    }
-
-    foreach my $key (@hashkeys, @sk) {
+    my @r;
+    foreach my $key (@hashkeys) {
 	my $dlen = $sep1 + $sep2 + length($key) + length($hash->{$key});
-	last if $len + $dlen > $maxlen
-	    && @r > 0;      # always include at least one key-value pair
+	last if @r > 0 && $len + $dlen > $maxlen;
 	push @r, [ $key, $hash->{$key} ];
 	$len += $dlen;
     }
+    while (my ($key,$val) = each %$hk1) {
+        next if $hk1_skip_key && defined($key{$key});
+	my $dlen = $sep1 + $sep2 + length($key) + length($val);
+	last if @r > 0 && $len + $dlen > $maxlen;
+	push @r, [ $key, $val ];
+	$len += $dlen;
+    }
+    Hash::SafeKeys::restore_iterator_state($hash, $it);
     return @r, [ $DOTDOTDOT ];
 }
 
@@ -325,7 +333,7 @@ Text::Shorten - Abbreviate long output
 
 =head1 VERSION
 
-0.06
+0.08
 
 =head1 SYNOPSIS
 
@@ -343,6 +351,7 @@ is abbreviated.
 
 =head1 FUNCTIONS
 
+=head2 shorten_scalar
 
 =head2 shorten_scalar($SCALAR, $MAXLEN)
 
@@ -366,6 +375,7 @@ precision of the number to fit it into the alloted space.
 The output of this function is not guaranteed to make sense
 when C<$MAXLEN> is small, say, less than 10.
 
+=head2 shorten_array
 
 =head2 shorten_array($ARRAYREF, $MAXLEN [,$SEPARATOR=1 [,@KEY=()]])
 
@@ -399,6 +409,7 @@ makes the output length exceed C<$MAXLEN>,
 The output of this function is not guaranteed to make sense
 when C<$MAXLEN> is small (say, less than 15).
 
+=head2 shorten_hash
 
 =head2 shorten_hash($HASHREF, $MAXLEN [, $SEP1=1, $SEP2=2 [, @KEY=() ]])
 
@@ -491,7 +502,7 @@ L<Dumpvalue> / C<dumpvars.pl>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2013 Marty O'Brien.
+Copyright 2010-2016 Marty O'Brien.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
